@@ -1,2 +1,2 @@
-setClassUnion("vectororNULL", c("vector","NULL"))
+# setClassUnion("vectororNULL", c("vector","NULL"))
 setClassUnion("OptionalParameter", c("Parameter","NULL"))
